.. _constituents_api:

Constituents
============

.. autoclass:: sasktran2.constituent.Rayleigh

.. autoclass:: sasktran2.constituent.VMRAltitudeAbsorber

.. autoclass:: sasktran2.constituent.NumberDensityScatterer

.. autoclass:: sasktran2.constituent.ExtinctionScatterer

Surfaces
--------

.. autoclass:: sasktran2.constituent.LambertianSurface


Dummy Constituents
------------------

.. autoclass:: sasktran2.constituent.AirMassFactor
